@@ -12,10 +12,10 @@
 #' @param assignment_path
 #'   Assignment file to set before marking the assignment (url or local path).
 #' @param force_get_tests
-#'   Force download of test files before marking of assignments. Default is FALSE.
+#'   Argument is deprecated, use \code{set_assignment()} instead.
 #' @param quiet
 #'   Should test be run without output?
-#' @param reporter to use. Default is the 'summary' or specified in assignment yml file.
+#' @param ... further arguments sent to \code{test_dir()}.
 #' 
 #' @examples
 #' assignment_path <- 
@@ -24,27 +24,36 @@
 #' mark_my_file(mark_file = file_path, assignment_path = assignment_path)
 #' 
 #' @export
-mark_my_file <- function(tasks = NULL, mark_file=file.choose(), assignment_path, force_get_tests = FALSE, quiet = FALSE, reporter){
+mark_my_file <- function(tasks = NULL, mark_file=file.choose(), assignment_path = NULL, force_get_tests = FALSE, quiet = FALSE, ...){
+  checkmate::assert_character(tasks, null.ok = TRUE)
+  checkmate::assert_file_exists(mark_file)
+  checkmate::assert_string(assignment_path, null.ok = TRUE)
+  checkmate::assert_flag(force_get_tests)
+  checkmate::assert_flag(quiet)
   
-  if(!missing(assignment_path)) {
+  if(force_get_tests){
+    .Deprecated("set_assignment()", old = "force_get_tests")
+  }
+  
+  if(!is.null(assignment_path)) {
     old_warn_opt <- options(warn = 2)
     set_assgn_result <- try(suppressMessages(set_assignment(assignment_path)), silent = TRUE)
     options(warn = old_warn_opt$warn)
     if(is(set_assgn_result, "try-error"))
       stop(set_assgn_result[1])
   }
-  if(missing(reporter)) reporter <- get_mark_my_reporter()
   
-  assert_function_arguments_in_API(
-    tasks = tasks, mark_file = mark_file, lab_file = assignment_path,
-    force_get_tests = force_get_tests, quiet = quiet, reporter = reporter)
-  
-  
-  get_tests(tasks = tasks, force_get_tests = force_get_tests)
-  test_results <- run_test_suite("mark_my_file", tasks, mark_file, quiet, reporter = reporter)
+  if(quiet){
+    capture_output(test_results <- suppressMessages(run_test_suite(caller = "mark_my_file", tasks, mark_file, quiet, ...)))
+  } else {
+    test_results <- run_test_suite(caller = "mark_my_file", tasks, mark_file, quiet, ...)
+  }
+
   test_results_df <- as.data.frame(test_results)
   if(!any(test_results_df$error) & sum(test_results_df$failed) == 0 & is.null(tasks) & !quiet) cheer()
-  check_existance_tasks(tasks = tasks)
+
+  if(!is.null(assignment_path)) remove_assignment()
+  
   return(invisible(test_results))
 }
 
